@@ -100,7 +100,8 @@ fitAdaptRandom2 <- function(outcomes,freq,nclass=2,initoutcomep,initclassp,initl
     }
     # penalise extreme outcome probabilities
     outcomep <- as.vector(1/(1+exp(abs(outcomex))))
-    pen <- dbeta(outcomep,1+penalty,1+penalty,log=TRUE)
+#    pen <- dbeta(outcomep,1+penalty,1+penalty,log=TRUE)
+    pen <-SciencesPo::ddirichlet(matrix(outcomep,nrow=1),rep(1+penalty/(nclass*2),length(outcomep)),log=TRUE)-SciencesPo::ddirichlet(matrix(outcomep,nrow=1),rep(1,length(outcomep)),log=TRUE)
     penll <- ll+sum(pen)
     if (is.nan(penll) || is.infinite(penll)) penll <- -1.0*.Machine$double.xmax
     if (calcfitted) {
